@@ -39,7 +39,7 @@
 *     July     14 1993: comment changes and addition of #pragma fenv_access.   *
 *     May      06 1997: port of the ibm/taligent ceil and floor routines.      *
 *     April    11 2001: first port to os x using gcc.                          *
-*     June     13 2001: replaced __setflm with fegetenvd/fesetenvd;            *
+*     June     13 2001: replaced __setflm with FEGETENVD/FESETENVD;            *
 *                       replaced DblInHex typedef with hexdouble.              *
 *                       used standard exception symbols from fenv.h.           *
 *     Sept     06 2001: added #ifdef __ppc__.                                  *
@@ -79,6 +79,7 @@ static const float         twoTo23  = 8388608.0;
 *      Ceil(x) returns the smallest integer not less than x.                   *
 *******************************************************************************/
 
+#ifdef notdef
 double ceil ( double x )
       {
       hexdouble xInHex, OldEnvironment;
@@ -104,9 +105,9 @@ double ceil ( double x )
                         return ( x );
                   else 
                         {                                  // inexact case
-                        fegetenvd( OldEnvironment.d );
+                        FEGETENVD( OldEnvironment.d );
                         OldEnvironment.i.lo |= FE_INEXACT;
-                        fesetenvd( OldEnvironment.d );
+                        FESETENVD( OldEnvironment.d );
                         if ( target )
                               return ( 1.0 );
                         else
@@ -166,9 +167,9 @@ float ceilf ( float x )
                         return ( x );
                   else 
                         {                                  // inexact case
-                        fegetenvd( OldEnvironment.d );
+                        FEGETENVD( OldEnvironment.d );
                         OldEnvironment.i.lo |= FE_INEXACT;
-                        fesetenvd( OldEnvironment.d );
+                        FESETENVD( OldEnvironment.d );
                         if ( target )
                               return ( 1.0 );
                         else
@@ -209,6 +210,9 @@ float ceilf ( float x )
 *******************************************************************************/
       return ( x );
       }
+      
+
+
 
 /*******************************************************************************
 *      Floor(x) returns the largest integer not greater than x.                *
@@ -239,9 +243,9 @@ double floor ( double x )
                         return ( x );
                   else 
                         {                                  // inexact case
-                        fegetenvd( OldEnvironment.d );
+                        FEGETENVD( OldEnvironment.d );
                         OldEnvironment.i.lo |= FE_INEXACT;
-                        fesetenvd( OldEnvironment.d );
+                        FESETENVD( OldEnvironment.d );
                         if ( target )
                               return ( 0.0 );
                         else
@@ -301,9 +305,9 @@ float floorf ( float x )
                         return ( x );
                   else 
                         {                                  // inexact case
-                        fegetenvd( OldEnvironment.d );
+                        FEGETENVD( OldEnvironment.d );
                         OldEnvironment.i.lo |= FE_INEXACT;
-                        fesetenvd( OldEnvironment.d );
+                        FESETENVD( OldEnvironment.d );
                         if ( target )
                               return ( 0.0 );
                         else
@@ -336,6 +340,257 @@ float floorf ( float x )
 *******************************************************************************/
       return ( x );
       }
+#else
+static const double piOver4 = 0.785398163397448390;        // 0x1.921fb54442d19p-1
+
+double ceil ( double x )
+{
+      register double y;
+      register int target;
+      
+      register double FPR_absx, FPR_Two52, FPR_one, FPR_zero, FPR_Mzero, FPR_pi4;
+      
+      FPR_absx = __FABS( x );				FPR_zero = 0.0;
+      FPR_Two52 = twoTo52;				FPR_one = 1.0;
+      __ENSURE( FPR_zero, FPR_Two52, FPR_one );
+      FPR_pi4 = piOver4;				FPR_Mzero = -0.0;
+      target = ( x > FPR_zero ); 			__ENSURE( FPR_Mzero, FPR_Two52, FPR_pi4 );
+           
+      if ( FPR_absx < FPR_Two52 ) 
+/*******************************************************************************
+*      Is |x| < 2.0^52?                                                        *
+*******************************************************************************/
+      {
+            if ( FPR_absx < FPR_one ) 
+/*******************************************************************************
+*      Is |x| < 1.0?                                                           *
+*******************************************************************************/
+            {
+                  if ( x == FPR_zero )  // zero x is exact case
+                        return ( x );
+                  else 
+                  {                                  // inexact case
+                        __PROG_INEXACT( FPR_pi4 );
+                        if ( target )
+                              return ( FPR_one );
+                        else
+                              return ( FPR_Mzero );
+                  }
+            }
+/*******************************************************************************
+*      Is 1.0 < |x| < 2.0^52?                                                  *
+*******************************************************************************/
+            if ( target ) 
+            {
+                  y = ( x + FPR_Two52 ) - FPR_Two52;          // round at binary pt.
+                  if ( y < x )
+                        return ( y + FPR_one );
+                  else
+                        return ( y );
+            }
+            
+            else 
+            {
+                  y = ( x - FPR_Two52 ) + FPR_Two52;          // round at binary pt.
+                  if ( y < x )
+                        return ( y + FPR_one );
+                  else
+                        return ( y );
+            }
+      }
+/*******************************************************************************
+*      |x| >= 2.0^52 or x is a NaN.                                            *
+*******************************************************************************/
+      return ( x );
+}
+
+float ceilf ( float x )
+{
+      register float y;
+      register int target;
+      
+      register float FPR_absx, FPR_Two23, FPR_one, FPR_zero, FPR_Mzero, FPR_pi4;
+      
+      FPR_absx = __FABS( x );				FPR_zero = 0.0f;
+      FPR_Two23 = twoTo23;				FPR_one = 1.0;
+      __ENSURE( FPR_zero, FPR_Two23, FPR_one );
+      FPR_pi4 = piOver4;				FPR_Mzero = -0.0f;
+      target = ( x > FPR_zero ); 			__ENSURE( FPR_Mzero, FPR_Two23, FPR_pi4 );
+           
+      if ( FPR_absx < FPR_Two23 ) 
+/*******************************************************************************
+*      Is |x| < 2.0^23?                                                        *
+*******************************************************************************/
+      {
+            if ( FPR_absx < FPR_one ) 
+/*******************************************************************************
+*      Is |x| < 1.0?                                                           *
+*******************************************************************************/
+            {
+                  if ( x == FPR_zero )  // zero x is exact case
+                        return ( x );
+                  else 
+                  {                                  // inexact case
+                        __PROG_INEXACT( FPR_pi4 );
+                        if ( target )
+                              return ( FPR_one );
+                        else
+                              return ( FPR_Mzero );
+                  }
+            }
+/*******************************************************************************
+*      Is 1.0 < |x| < 2.0^23?                                                  *
+*******************************************************************************/
+            if ( target ) 
+            {
+                  y = ( x + FPR_Two23 ) - FPR_Two23;          // round at binary pt.
+                  if ( y < x )
+                        return ( y + FPR_one );
+                  else
+                        return ( y );
+            }
+            
+            else 
+            {
+                  y = ( x - FPR_Two23 ) + FPR_Two23;          // round at binary pt.
+                  if ( y < x )
+                        return ( y + FPR_one );
+                  else
+                        return ( y );
+            }
+      }
+/*******************************************************************************
+*      |x| >= 2.0^23 or x is a NaN.                                            *
+*******************************************************************************/
+      return ( x );
+}
+
+/*******************************************************************************
+*      Floor(x) returns the largest integer not greater than x.                *
+*******************************************************************************/
+
+double floor ( double x )
+{
+      register double y;
+      register int target;
+      
+      register double FPR_absx, FPR_Two52, FPR_one, FPR_zero, FPR_Mone, FPR_pi4;
+      
+      FPR_absx = __FABS( x );				FPR_zero = 0.0;
+      FPR_Two52 = twoTo52;				FPR_one = 1.0;
+      __ENSURE( FPR_zero, FPR_Two52, FPR_one );
+      FPR_pi4 = piOver4;				FPR_Mone = -1.0;
+      target = ( x > FPR_zero ); 			__ENSURE( FPR_Mone, FPR_zero, FPR_pi4 );
+           
+      if ( FPR_absx < FPR_Two52 ) 
+/*******************************************************************************
+*      Is |x| < 2.0^52?                                                        *
+*******************************************************************************/
+      {
+            if ( FPR_absx < FPR_one ) 
+/*******************************************************************************
+*      Is |x| < 1.0?                                                           *
+*******************************************************************************/
+            {
+                  if ( x == FPR_zero )  // zero x is exact case
+                        return ( x );
+                  else 
+                  {                                  // inexact case
+                        __PROG_INEXACT( FPR_pi4 );
+                        if ( target )
+                              return ( FPR_zero );
+                        else
+                              return ( FPR_Mone );
+                  }
+            }
+/*******************************************************************************
+*      Is 1.0 < |x| < 2.0^52?                                                  *
+*******************************************************************************/
+            if ( target ) 
+            {
+                  y = ( x + FPR_Two52 ) - FPR_Two52;          // round at binary pt.
+                  if ( y > x )
+                        return ( y - FPR_one );
+                  else
+                        return ( y );
+            }
+            
+            else 
+            {
+                  y = ( x - FPR_Two52 ) + FPR_Two52;          // round at binary pt.
+                  if ( y > x )
+                        return ( y - FPR_one );
+                  else
+                        return ( y );
+            }
+      }
+/*******************************************************************************
+*      |x| >= 2.0^52 or x is a NaN.                                            *
+*******************************************************************************/
+      return ( x );
+}
+
+float floorf ( float x )
+{
+      register float y;
+      register int target;
+      
+      register float FPR_absx, FPR_Two23, FPR_one, FPR_zero, FPR_Mone, FPR_pi4;
+      
+      FPR_absx = __FABS( x );				FPR_zero = 0.0f;
+      FPR_Two23 = twoTo23;				FPR_one = 1.0f;
+      __ENSURE( FPR_zero, FPR_Two23, FPR_one );
+      FPR_pi4 = piOver4;				FPR_Mone = -1.0f;
+      target = ( x > FPR_zero ); 			__ENSURE( FPR_Mone, FPR_zero, FPR_pi4 );
+           
+      if ( FPR_absx < FPR_Two23 ) 
+/*******************************************************************************
+*      Is |x| < 2.0^23?                                                        *
+*******************************************************************************/
+      {
+            if ( FPR_absx < FPR_one ) 
+/*******************************************************************************
+*      Is |x| < 1.0?                                                           *
+*******************************************************************************/
+            {
+                  if ( x == FPR_zero )  // zero x is exact case
+                        return ( x );
+                  else 
+                  {                                  // inexact case
+                        __PROG_INEXACT( FPR_pi4 );
+                        if ( target )
+                              return ( FPR_zero );
+                        else
+                              return ( FPR_Mone );
+                  }
+            }
+/*******************************************************************************
+*      Is 1.0 < |x| < 2.0^23?                                                  *
+*******************************************************************************/
+            if ( target ) 
+            {
+                  y = ( x + FPR_Two23 ) - FPR_Two23;          // round at binary pt.
+                  if ( y > x )
+                        return ( y - FPR_one );
+                  else
+                        return ( y );
+            }
+            
+            else 
+            {
+                  y = ( x - FPR_Two23 ) + FPR_Two23;          // round at binary pt.
+                  if ( y > x )
+                        return ( y - FPR_one );
+                  else
+                        return ( y );
+            }
+      }
+/*******************************************************************************
+*      |x| >= 2.0^23 or x is a NaN.                                            *
+*******************************************************************************/
+      return ( x );
+}
+#endif
 
 #else       /* __APPLE_CC__ version */
 #warning A higher version than gcc-932 is required.
